@@ -31,6 +31,9 @@ from .base import (
     safe_division,
 )
 
+# Pattern Indicators
+from .fvg import FVG as FVGIndicator, calculate_fvg
+
 # Momentum Indicators
 from .momentum import (
     # NEW MOMENTUM INDICATORS
@@ -76,6 +79,7 @@ from .momentum import (
     calculate_ultimate_oscillator,
     calculate_williams_r,
 )
+from .order_block import OrderBlock as OrderBlockIndicator, calculate_order_block
 
 # Overlap Studies (Trend Indicators)
 from .overlap import (
@@ -117,8 +121,10 @@ from .overlap import (
 from .volatility import (
     ATR as ATRIndicator,
     NATR as NATRIndicator,
+    STDDEV as STDDEVIndicator,
     TRANGE as TRANGEIndicator,
     calculate_atr,
+    calculate_stddev,
 )
 
 # Volume Indicators
@@ -130,9 +136,10 @@ from .volume import (
     calculate_obv,
     calculate_vwap,
 )
+from .waddah_attar import WAE as WAEIndicator, calculate_wae
 
 # Version info
-__version__ = "1.1.1"
+__version__ = "2.0.3"
 __author__ = "TexasCoding"
 
 
@@ -653,6 +660,11 @@ def TRANGE(data, high_column="high", low_column="low", close_column="close"):
     )
 
 
+def STDDEV(data, column="close", period=5, ddof=1):
+    """Standard Deviation (TA-Lib style)."""
+    return calculate_stddev(data, column=column, period=period, ddof=ddof)
+
+
 # Volume Indicators
 def OBV(data, close_column="close", volume_column="volume"):
     """On-Balance Volume (TA-Lib style)."""
@@ -716,6 +728,86 @@ def ADOSC(
     )
 
 
+# Pattern Indicators
+def FVG(
+    data,
+    high_column="high",
+    low_column="low",
+    close_column="close",
+    min_gap_size=0.0,
+    check_mitigation=False,
+    mitigation_threshold=0.5,
+):
+    """Fair Value Gap (TA-Lib style)."""
+    return calculate_fvg(
+        data,
+        high_column=high_column,
+        low_column=low_column,
+        close_column=close_column,
+        min_gap_size=min_gap_size,
+        check_mitigation=check_mitigation,
+        mitigation_threshold=mitigation_threshold,
+    )
+
+
+def ORDERBLOCK(
+    data,
+    open_column="open",
+    high_column="high",
+    low_column="low",
+    close_column="close",
+    volume_column="volume",
+    min_volume_percentile=50,
+    check_mitigation=False,
+    mitigation_threshold=0.5,
+    lookback_periods=3,
+    use_wicks=True,
+):
+    """Order Block (TA-Lib style)."""
+    return calculate_order_block(
+        data,
+        open_column=open_column,
+        high_column=high_column,
+        low_column=low_column,
+        close_column=close_column,
+        volume_column=volume_column,
+        min_volume_percentile=min_volume_percentile,
+        check_mitigation=check_mitigation,
+        mitigation_threshold=mitigation_threshold,
+        lookback_periods=lookback_periods,
+        use_wicks=use_wicks,
+    )
+
+
+def WAE(
+    data,
+    close_column="close",
+    high_column="high",
+    low_column="low",
+    fast_period=20,
+    slow_period=40,
+    bb_period=20,
+    bb_mult=2.0,
+    sensitivity=150,
+    dead_zone_period=100,
+    dead_zone_mult=3.6,
+):
+    """Waddah Attar Explosion (TA-Lib style)."""
+    return calculate_wae(
+        data,
+        close_column=close_column,
+        high_column=high_column,
+        low_column=low_column,
+        fast_period=fast_period,
+        slow_period=slow_period,
+        bb_period=bb_period,
+        bb_mult=bb_mult,
+        sensitivity=sensitivity,
+        dead_zone_period=dead_zone_period,
+        dead_zone_mult=dead_zone_mult,
+    )
+
+
 # Helper functions for indicator discovery
 def get_indicator_groups():
     """Get available indicator groups."""
@@ -771,8 +863,9 @@ def get_indicator_groups():
             "TRIX",
             "ULTOSC",
         ],
-        "volatility": ["ATR", "NATR", "TRANGE"],
+        "volatility": ["ATR", "NATR", "TRANGE", "STDDEV"],
         "volume": ["OBV", "VWAP", "AD", "ADOSC"],
+        "patterns": ["FVG", "ORDERBLOCK", "WAE"],
     }
 
 
@@ -841,11 +934,16 @@ def get_indicator_info(indicator_name):
         "ATR": "Average True Range - measures market volatility by analyzing the range of price movements",
         "NATR": "Normalized Average True Range - ATR as percentage of closing price",
         "TRANGE": "True Range - measures the actual range of price movement for a single period",
+        "STDDEV": "Standard Deviation - measures the dispersion of prices from the mean",
         # Volume Indicators
         "OBV": "On-Balance Volume - cumulative indicator relating volume to price change",
         "VWAP": "Volume Weighted Average Price - average price weighted by volume",
         "AD": "Accumulation/Distribution Line - volume-based indicator showing money flow",
         "ADOSC": "Accumulation/Distribution Oscillator - difference between fast and slow A/D Line EMAs",
+        # Pattern Indicators
+        "FVG": "Fair Value Gap - identifies price imbalance areas that may act as support/resistance",
+        "ORDERBLOCK": "Order Block - identifies institutional order zones based on price action patterns",
+        "WAE": "Waddah Attar Explosion - identifies strong trends and breakouts using MACD and Bollinger Bands",
     }
 
     return indicator_map.get(indicator_name.upper(), "Indicator not found")
@@ -861,6 +959,7 @@ __all__ = [
     "CCI",
     "DEMA",
     "EMA",
+    "FVG",
     "HT_TRENDLINE",
     "KAMA",
     "MA",
@@ -872,12 +971,14 @@ __all__ = [
     "MOM",
     "NATR",
     "OBV",
+    "ORDERBLOCK",
     "ROC",
     "RSI",
     "SAR",
     "SAREXT",
     # Class-based indicators (import from modules)
     "SMA",
+    "STDDEV",
     "STOCH",
     "STOCHRSI",
     "T3",
@@ -886,6 +987,7 @@ __all__ = [
     "TRIMA",
     "ULTOSC",
     "VWAP",
+    "WAE",
     "WILLR",
     "WMA",
     # Base classes
@@ -902,6 +1004,7 @@ __all__ = [
     "calculate_commodity_channel_index",
     "calculate_dema",
     "calculate_ema",
+    "calculate_fvg",
     "calculate_ht_trendline",
     "calculate_kama",
     "calculate_ma",
@@ -911,17 +1014,20 @@ __all__ = [
     "calculate_midprice",
     "calculate_money_flow_index",
     "calculate_obv",
+    "calculate_order_block",
     "calculate_ppo",
     "calculate_rsi",
     "calculate_sar",
     # Function-based indicators (convenience functions)
     "calculate_sma",
+    "calculate_stddev",
     "calculate_stochastic",
     "calculate_t3",
     "calculate_tema",
     "calculate_trima",
     "calculate_ultimate_oscillator",
     "calculate_vwap",
+    "calculate_wae",
     "calculate_williams_r",
     "calculate_wma",
     # Utilities
