@@ -1,19 +1,16 @@
 """Test order creation and submission functionality."""
 
-from datetime import datetime, timezone
-from decimal import Decimal
-from unittest.mock import MagicMock, Mock, patch
+from datetime import UTC, datetime
+from unittest.mock import Mock, patch
 
-import polars as pl
 import pytest
 
 from project_x_py import ProjectX
 from project_x_py.exceptions import (
     ProjectXConnectionError,
-    ProjectXError,
     ProjectXOrderError,
 )
-from project_x_py.models import Account, Instrument, Order, OrderPlaceResponse, Position
+from project_x_py.models import Account, Instrument, Order, Position
 from project_x_py.order_manager import OrderManager
 
 
@@ -410,7 +407,7 @@ class TestOrderCreation:
             id=12345,
             accountId=1001,
             contractId="ES",
-            creationTimestamp=datetime.now(timezone.utc).isoformat(),
+            creationTimestamp=datetime.now(UTC).isoformat(),
             updateTimestamp=None,
             status=1,  # Pending
             type=1,  # Limit
@@ -465,7 +462,7 @@ class TestOrderCreation:
                         "id": 12345,
                         "accountId": 1001,
                         "contractId": "ES",
-                        "creationTimestamp": datetime.now(timezone.utc).isoformat(),
+                        "creationTimestamp": datetime.now(UTC).isoformat(),
                         "updateTimestamp": None,
                         "status": 1,
                         "type": 1,
@@ -479,7 +476,7 @@ class TestOrderCreation:
                         "id": 12346,
                         "accountId": 1001,
                         "contractId": "NQ",
-                        "creationTimestamp": datetime.now(timezone.utc).isoformat(),
+                        "creationTimestamp": datetime.now(UTC).isoformat(),
                         "updateTimestamp": None,
                         "status": 1,
                         "type": 2,
@@ -510,7 +507,7 @@ class TestOrderCreation:
             id=1,
             accountId=1001,
             contractId="ES",
-            creationTimestamp=datetime.now(timezone.utc).isoformat(),
+            creationTimestamp=datetime.now(UTC).isoformat(),
             type=1,  # Long
             size=2,
             averagePrice=4500.0,
@@ -549,7 +546,7 @@ class TestOrderCreation:
             id=1,
             accountId=1001,
             contractId="ES",
-            creationTimestamp=datetime.now(timezone.utc).isoformat(),
+            creationTimestamp=datetime.now(UTC).isoformat(),
             type=1,  # Long
             size=1,
             averagePrice=4500.0,
